@@ -1,5 +1,5 @@
 class Aspect:
-    def main(txt):
+    def recognizer(txt):
         nlp = stanza.Pipeline('en')
         txt = txt.lower()
         sentList = nltk.sent_tokenize(txt)
